@@ -232,7 +232,7 @@ void SKGBookmarkPluginDockWidget::openBookmark(const SKGNodeObject& iNode, bool
                 }
                 SKGTabWidget* tab = SKGMainPanel::getMainPanel()->getTabWidget();
                 if (tab) {
-                    tab->setTabIcon(SKGMainPanel::getMainPanel()->currentPageIndex(), selectedNode.getIcon());
+                    tab->setTabIcon(tab->indexOf(page), selectedNode.getIcon());
                 }
                 selectedNode.opened = true;
                 tabNumberForNextOpen = -1;
