@@ -99,9 +99,9 @@ SKGBankPluginWidget::SKGBankPluginWidget(SKGDocumentBank* iDocument)
 
             m_timer2.setSingleShot(true);
             connect(&m_timer2, SIGNAL(timeout()), this, SLOT(onRefreshGraph()), Qt::QueuedConnection);
-            m_timer2.start(300);
+            onRefreshGraphDelayed();
 
-            connect(ui.kView->getShowWidget(), SIGNAL(stateChanged()), &m_timer2, SIGNAL(timeout()));
+            connect(ui.kView->getShowWidget(), SIGNAL(stateChanged()), this, SLOT(onRefreshGraphDelayed()), Qt::QueuedConnection);
         }
     }
 
@@ -335,6 +335,11 @@ void SKGBankPluginWidget::onSelectionChanged()
     Q_EMIT selectionChanged();
 }
 
+void SKGBankPluginWidget::onRefreshGraphDelayed()
+{
+    m_timer2.start(300);
+}
+
 void SKGBankPluginWidget::onRefreshGraph()
 {
     SKGTRACEINFUNC(10);
@@ -379,8 +384,11 @@ void SKGBankPluginWidget::onRefreshGraph()
             }
             root.setAttribute("graph", doc2.toString());
         }
-
-        m_graph->setState(doc.toString());
+        QString newGraphState = doc.toString();
+        if (newGraphState != m_graphState) {
+            m_graphState = newGraphState;
+            m_graph->setState(m_graphState);
+        }
 
         m_graph->setVisible(visible);
     }
