@@ -21,6 +21,8 @@
 *
 * @author Stephane MANKOWSKI / Guillaume DE BURE
 */
+#include <QTimer>
+
 #include "ui_skgoperationpluginwidget_board.h"
 #include "skgboardwidget.h"
 
@@ -62,6 +64,7 @@ public:
     virtual void setState(const QString& iState);
 
 private Q_SLOTS:
+    void refreshDelayed();
     void dataModified(const QString& iTableName = "", int iIdTransaction = 0);
     void onOpen(const QString& iLink);
 
@@ -79,6 +82,8 @@ private:
     SKGPeriodEdit* m_periodEdit2;
 
     QParallelAnimationGroup* m_anim;
+
+    QTimer m_timer;
 };
 
 #endif  // SKGOPERATIONBOARDWIDGET_H
