@@ -187,6 +187,126 @@ bool SKGReportPlugin::isInPagesChooser() const
     return true;
 }
 
+void SKGReportPlugin::getTitleAndWhereClause(const SKGObjectBase::SKGListSKGObjectBase& iSelection, QString& oTitle, QString& oWhereClause) const
+{
+    int nb = iSelection.count();
+    if (nb > 0) {
+        QString table = iSelection.at(0).getRealTable();
+        if (table == "account") {
+            oWhereClause = "rd_account_id in (";
+            oTitle = i18nc("Noun, a list of items", "Operations of account ");
+
+            for (int i = 0; i < nb; ++i) {
+                SKGAccountObject tmp(iSelection.at(i));
+                if (i) {
+                    oWhereClause += ',';
+                    oTitle += ',';
+                }
+                oWhereClause += SKGServices::intToString(tmp.getID());
+                oTitle += i18n("'%1'", tmp.getName());
+            }
+            oWhereClause += ')';
+        } else if (table == "unit") {
+            oWhereClause = "rc_unit_id in (";
+            oTitle = i18nc("Noun, a list of items", "Operations with Unit equal to ");
+
+            for (int i = 0; i < nb; ++i) {
+                SKGUnitObject tmp(iSelection.at(i));
+                if (i) {
+                    oWhereClause += ',';
+                    oTitle += ',';
+                }
+                oWhereClause += SKGServices::intToString(tmp.getID());
+                oTitle += i18n("'%1'", tmp.getName());
+            }
+            oWhereClause += ')';
+        } else if (table == "category") {
+            oWhereClause = "t_REALCATEGORY in (";
+            QString wc2;
+            oTitle = i18nc("Noun, a list of items", "Operations with Category equal to ");
+
+            for (int i = 0; i < nb; ++i) {
+                SKGCategoryObject tmp(iSelection.at(i));
+                if (i) {
+                    oWhereClause += ',';
+                    wc2 += " OR ";
+                    oTitle += ',';
+                }
+                oWhereClause += '\'' % SKGServices::stringToSqlString(tmp.getFullName()) % '\'';
+                wc2 += "t_REALCATEGORY like '" % SKGServices::stringToSqlString(tmp.getFullName()) % "%'";
+                oTitle += i18n("'%1'", tmp.getFullName());
+            }
+            oWhereClause += ") OR " % wc2;
+        } else if (table == "refund") {
+            oWhereClause = "r_refund_id in (";
+            oTitle = i18nc("Noun, a list of items", "Operations followed by ");
+
+            for (int i = 0; i < nb; ++i) {
+                SKGTrackerObject tmp(iSelection.at(i));
+                if (i) {
+                    oWhereClause += ',';
+                    oTitle += ',';
+                }
+                oWhereClause += SKGServices::intToString(tmp.getID());
+                oTitle += i18n("'%1'", tmp.getName());
+            }
+            oWhereClause += ')';
+        } else if (table == "payee") {
+            oWhereClause = "r_payee_id in (";
+            oTitle = i18nc("Noun, a list of items", "Operations assigned to ");
+
+            for (int i = 0; i < nb; ++i) {
+                SKGPayeeObject tmp(iSelection.at(i));
+                if (i) {
+                    oWhereClause += ',';
+                    oTitle += ',';
+                }
+                oWhereClause += SKGServices::intToString(tmp.getID());
+                oTitle += i18n("'%1'", tmp.getName());
+            }
+            oWhereClause += ')';
+        } else if (table == "operation") {
+            oWhereClause = "i_OPID in (";
+            oTitle = i18nc("Noun, a list of items", "Selected operations");
+
+            for (int i = 0; i < nb; ++i) {
+                if (i) {
+                    oWhereClause += ',';
+                }
+                oWhereClause += SKGServices::intToString(iSelection.at(i).getID());
+            }
+            oWhereClause += ')';
+        } else if (table == "suboperation") {
+            oWhereClause = "i_SUBOPID in (";
+            oTitle = i18nc("Noun, a list of items", "Selected sub operations");
+
+            for (int i = 0; i < nb; ++i) {
+                if (i) {
+                    oWhereClause += ',';
+                }
+                oWhereClause += SKGServices::intToString(iSelection.at(i).getID());
+            }
+            oWhereClause += ')';
+        } else if (table == "rule") {
+            oTitle = i18nc("Noun, a list of items", "Operations corresponding to rule ");
+
+            for (int i = 0; i < nb; ++i) {
+                SKGRuleObject tmp(iSelection.at(i));
+                QString ruleWc = tmp.getSelectSqlOrder();
+                if (!ruleWc.isEmpty()) {
+                    if (!oWhereClause.isEmpty()) {
+                        oWhereClause += " OR ";
+                        oTitle += ',';
+                    }
+                    oWhereClause += '(' % ruleWc % ')';
+                    oTitle += i18n("'%1'", tmp.getSearchDescription());
+                }
+            }
+        }
+    }
+}
+
+
 void SKGReportPlugin::onOpenReport()
 {
     SKGError err;
@@ -196,120 +316,9 @@ void SKGReportPlugin::onOpenReport()
 
         int nb = selection.count();
         if (nb > 0) {
-            QString wc;
             QString titleTable;
-            QString table = selection.at(0).getRealTable();
-            if (table == "account") {
-                wc = "rd_account_id in (";
-                titleTable = i18nc("Noun, a list of items", "Operations of account ");
-
-                for (int i = 0; i < nb; ++i) {
-                    SKGAccountObject tmp(selection.at(i));
-                    if (i) {
-                        wc += ',';
-                        titleTable += ',';
-                    }
-                    wc += SKGServices::intToString(tmp.getID());
-                    titleTable += i18n("'%1'", tmp.getName());
-                }
-                wc += ')';
-            } else if (table == "unit") {
-                wc = "rc_unit_id in (";
-                titleTable = i18nc("Noun, a list of items", "Operations with Unit equal to ");
-
-                for (int i = 0; i < nb; ++i) {
-                    SKGUnitObject tmp(selection.at(i));
-                    if (i) {
-                        wc += ',';
-                        titleTable += ',';
-                    }
-                    wc += SKGServices::intToString(tmp.getID());
-                    titleTable += i18n("'%1'", tmp.getName());
-                }
-                wc += ')';
-            } else if (table == "category") {
-                wc = "t_REALCATEGORY in (";
-                QString wc2;
-                titleTable = i18nc("Noun, a list of items", "Operations with Category equal to ");
-
-                for (int i = 0; i < nb; ++i) {
-                    SKGCategoryObject tmp(selection.at(i));
-                    if (i) {
-                        wc += ',';
-                        wc2 += " OR ";
-                        titleTable += ',';
-                    }
-                    wc += '\'' % SKGServices::stringToSqlString(tmp.getFullName()) % '\'';
-                    wc2 += "t_REALCATEGORY like '" % SKGServices::stringToSqlString(tmp.getFullName()) % "%'";
-                    titleTable += i18n("'%1'", tmp.getFullName());
-                }
-                wc += ") OR " % wc2;
-            } else if (table == "refund") {
-                wc = "r_refund_id in (";
-                titleTable = i18nc("Noun, a list of items", "Operations followed by ");
-
-                for (int i = 0; i < nb; ++i) {
-                    SKGTrackerObject tmp(selection.at(i));
-                    if (i) {
-                        wc += ',';
-                        titleTable += ',';
-                    }
-                    wc += SKGServices::intToString(tmp.getID());
-                    titleTable += i18n("'%1'", tmp.getName());
-                }
-                wc += ')';
-            } else if (table == "payee") {
-                wc = "r_payee_id in (";
-                titleTable = i18nc("Noun, a list of items", "Operations assigned to ");
-
-                for (int i = 0; i < nb; ++i) {
-                    SKGPayeeObject tmp(selection.at(i));
-                    if (i) {
-                        wc += ',';
-                        titleTable += ',';
-                    }
-                    wc += SKGServices::intToString(tmp.getID());
-                    titleTable += i18n("'%1'", tmp.getName());
-                }
-                wc += ')';
-            } else if (table == "operation") {
-                wc = "i_OPID in (";
-                titleTable = i18nc("Noun, a list of items", "Selected operations");
-
-                for (int i = 0; i < nb; ++i) {
-                    if (i) {
-                        wc += ',';
-                    }
-                    wc += SKGServices::intToString(selection.at(i).getID());
-                }
-                wc += ')';
-            } else if (table == "suboperation") {
-                wc = "i_SUBOPID in (";
-                titleTable = i18nc("Noun, a list of items", "Selected sub operations");
-
-                for (int i = 0; i < nb; ++i) {
-                    if (i) {
-                        wc += ',';
-                    }
-                    wc += SKGServices::intToString(selection.at(i).getID());
-                }
-                wc += ')';
-            } else if (table == "rule") {
-                titleTable = i18nc("Noun, a list of items", "Operations corresponding to rule ");
-
-                for (int i = 0; i < nb; ++i) {
-                    SKGRuleObject tmp(selection.at(i));
-                    QString ruleWc = tmp.getSelectSqlOrder();
-                    if (!ruleWc.isEmpty()) {
-                        if (!wc.isEmpty()) {
-                            wc += " OR ";
-                            titleTable += ',';
-                        }
-                        wc += '(' % ruleWc % ')';
-                        titleTable += i18n("'%1'", tmp.getSearchDescription());
-                    }
-                }
-            }
+            QString wc;
+            getTitleAndWhereClause(selection, titleTable, wc);
 
             // Call report plugin
             SKGMainPanel::getMainPanel()->openPage("skg://skrooge_report_plugin/?period=0&title_icon=" % icon() % "&title=" % SKGServices::encodeForUrl(titleTable) % "&operationWhereClause=" % SKGServices::encodeForUrl(wc));
