@@ -20,6 +20,7 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgreportpluginwidget.h"
+#include "skgreportplugin.h"
 
 #include <KLocale>
 #include <KMenu>
@@ -50,10 +51,6 @@ SKGReportPluginWidget::SKGReportPluginWidget(SKGDocumentBank* iDocument, bool iM
 
     ui.setupUi(this);
 
-    ui.kTitle->hide();
-    ui.kResetInternalFilter->hide();
-    ui.kResetInternalFilter->setIcon(KIcon("dialog-cancel"));
-
     ui.kCorrectedBy->setDocument(iDocument);
     ui.kCorrectedBy->setCurrentIndex(0);
     ui.kCorrectedBy->setWhereClauseCondition("t_type='I'");
@@ -171,6 +168,9 @@ SKGReportPluginWidget::SKGReportPluginWidget(SKGDocumentBank* iDocument, bool iM
 
     connect(getDocument(), SIGNAL(tableModified(QString,int,bool)), this, SLOT(dataModified(QString,int)));
     connect(SKGMainPanel::getMainPanel(), SIGNAL(currentPageChanged()), this, SLOT(pageChanged()), Qt::QueuedConnection);
+    connect(SKGMainPanel::getMainPanel(), SIGNAL(pageClosed()), this, SLOT(pageChanged()), Qt::QueuedConnection);
+    connect(ui.kOtherFilters, SIGNAL(itemChanged(QListWidgetItem*)), this, SLOT(pageChanged()), Qt::QueuedConnection);
+    connect(ui.kOtherFilters, SIGNAL(itemChanged(QListWidgetItem*)), this, SLOT(refresh()), Qt::QueuedConnection);
 
     if (iMinimmumMode) {
         ui.kTableWithGraph->getShowWidget()->setState("\"graph\"");
@@ -187,31 +187,12 @@ SKGReportPluginWidget::~SKGReportPluginWidget()
     m_openReportAction = NULL;
 }
 
-void SKGReportPluginWidget::onResetInternalFilter()
-{
-    SKGTRACEINFUNC(10);
-
-    // Initialisation
-    m_lastState.clear();
-    m_operationWhereClause = "";
-    ui.kTitle->hide();
-    ui.kResetInternalFilter->hide();
-
-    m_timer.start(300);
-}
-
 QString SKGReportPluginWidget::getState()
 {
     SKGTRACEINFUNC(10);
     QDomDocument doc("SKGML");
-    QDomElement root;
-    if (m_lastState.hasChildNodes()) {
-        doc = m_lastState;
-        root = doc.documentElement();
-    } else {
-        root = doc.createElement("parameters");
-        doc.appendChild(root);
-    }
+    QDomElement root = doc.createElement("parameters");
+    doc.appendChild(root);
 
     root.setAttribute("columns", m_attsForColumns.value(ui.kColumns->currentIndex()));
 
@@ -243,8 +224,29 @@ QString SKGReportPluginWidget::getState()
     root.setAttribute("correctedby", ui.kCorrectedBy->currentText());
     root.setAttribute("correctedbymode", ui.kCorrectedByMode->currentText());
 
-    if (!m_operationWhereClause.isEmpty()) {
-        root.setAttribute("operationWhereClause", m_operationWhereClause);
+    // Addition of other filter
+    QString wc;
+    QString title = root.attribute("title");
+    QString title_icon;
+    nb = ui.kOtherFilters->count();
+    for (int i = 0; i < nb; ++i) {
+        QListWidgetItem* item = ui.kOtherFilters->item(i);
+        if (item->checkState() == Qt::Checked) {
+            if (!wc.isEmpty()) {
+                wc = '(' % wc % ") AND (" % item->data(1000).toString() % ')';
+            } else {
+                wc = item->data(1000).toString();
+            }
+            title_icon = item->data(1001).toString();
+
+            title += item->text();
+        }
+    }
+
+    if (!wc.isEmpty()) {
+        root.setAttribute("title", title);
+        root.setAttribute("operationWhereClause", wc);
+        root.setAttribute("title_icon", title_icon);
     }
 
     return doc.toString();
@@ -274,7 +276,7 @@ void SKGReportPluginWidget::setState(const QString& iState)
     QString tableAndGraphState = root.attribute("tableAndGraphState");
     QString title = root.attribute("title");
     QString title_icon = root.attribute("title_icon");
-    m_operationWhereClause = root.attribute("operationWhereClause");
+    QString wc = root.attribute("operationWhereClause");
     QString nbLevelLinesString = root.attribute("nbLevelLines");
     QString nbLevelColumnsString = root.attribute("nbLevelColumns");
     QString zoomPositionString = root.attribute("zoomPosition");
@@ -392,24 +394,16 @@ void SKGReportPluginWidget::setState(const QString& iState)
     refresh();
 
     ui.kTableWithGraph->setState(tableAndGraphState);
-    if (!title.isEmpty()) {
-        ui.kTitle->setComment("<html><body><b>" % SKGServices::stringToHtml(title) % "</b></body></html>");
-        ui.kTitle->show();
-        ui.kResetInternalFilter->show();
-    } else {
-        ui.kTitle->hide();
-        ui.kResetInternalFilter->hide();
-    }
-    if (!title_icon.isEmpty()) {
-        ui.kTitle->setPixmap(KIcon(title_icon).pixmap(22, 22), KTitleWidget::ImageLeft);
-    }
-    if (!m_operationWhereClause.isEmpty()) {
-        // We keep a copy of given state in case of bookmark
-        m_lastState = doc;
-        m_timer.start(300);
-    } else {
-        m_lastState.clear();
+
+    if (!title.isEmpty() && !wc.isEmpty()) {
+        QListWidgetItem* item = new QListWidgetItem(KIcon(title_icon), title);
+        item->setCheckState(Qt::Checked);
+        item->setFlags(Qt::ItemIsUserCheckable | Qt::ItemIsEnabled);
+        item->setData(1000, wc);
+        item->setData(1001, title_icon);
+        ui.kOtherFilters->addItem(item);
     }
+
     m_previousParametersUsed = "";
 }
 
@@ -441,11 +435,15 @@ QList< QWidget* > SKGReportPluginWidget::printableWidgets()
 void SKGReportPluginWidget::getWhereClauseAndTitleForSelection(int row, int column, QString& oWc, QString& oTitle)
 {
     // Build where clause and title
-    QString currentComment = ui.kTitle->comment();
-    if (!currentComment.isEmpty()) {
-        currentComment.remove("<html><body><b>");
-        currentComment.remove("</b></body></html>");
-        oTitle = SKGServices::htmlToString(currentComment) % ". ";
+    oTitle.clear();
+
+    // Addition of other filter
+    int nb = ui.kOtherFilters->count();
+    for (int i = 0; i < nb; ++i) {
+        QListWidgetItem* item = ui.kOtherFilters->item(i);
+        if (item->checkState() == Qt::Checked) {
+            oTitle += item->text() % '.';
+        }
     }
 
     // Condition on line attribute
@@ -457,7 +455,7 @@ void SKGReportPluginWidget::getWhereClauseAndTitleForSelection(int row, int colu
     if (listAtt.count() == 0 || ui.kLines->currentIndex() > 0) {
         listAtt.push_back(m_attsForLines.at(ui.kLines->currentIndex()));
     }
-    int nb = listAtt.count();
+    nb = listAtt.count();
     for (int i = 0; i < nb; ++i) {
         QString att = listAtt.at(i);
         if (att == "#NOTHING#") {
@@ -703,11 +701,16 @@ QString SKGReportPluginWidget::getConsolidatedWhereClause(QString* oWhereClausFo
         }
     }
 
-    if (!m_operationWhereClause.isEmpty()) {
-        QString condition = " AND (" % m_operationWhereClause % ')';
-        wc += condition;
-        if (oWhereClausForPreviousData) {
-            *oWhereClausForPreviousData += condition;
+    // Addition of other filters
+    int nb = ui.kOtherFilters->count();
+    for (int i = 0; i < nb; ++i) {
+        QListWidgetItem* item = ui.kOtherFilters->item(i);
+        if (item->checkState() == Qt::Checked) {
+            QString condition = " AND (" % item->data(1000).toString() % ")";
+            wc += condition;
+            if (oWhereClausForPreviousData) {
+                *oWhereClausForPreviousData += condition;
+            }
         }
     }
 
@@ -760,6 +763,54 @@ void SKGReportPluginWidget::pageChanged()
     if (m_refreshNeeded) {
         m_timer.start(300);
     }
+
+    // Refresh other filter
+    SKGReportPlugin* rep = qobject_cast<SKGReportPlugin*>(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge report plugin"));
+    if (rep) {
+        // Remove unused filters
+        int nbf = ui.kOtherFilters->count();
+        for (int i = nbf - 1; i >= 0; --i) {
+            QListWidgetItem* item = ui.kOtherFilters->item(i);
+            if (item->checkState() == Qt::Unchecked) {
+                QListWidgetItem* item = ui.kOtherFilters->takeItem(i);
+                delete item;
+            }
+        }
+
+        // Add pages filters
+        int nb = SKGMainPanel::getMainPanel()->countPages();
+        for (int i = 0; i < nb; ++i) {
+            SKGTabPage* page = SKGMainPanel::getMainPanel()->page(i);
+            SKGObjectBase::SKGListSKGObjectBase selection = page->getSelectedObjects();
+
+            QString title;
+            QString wc;
+            rep->getTitleAndWhereClause(selection, title, wc);
+            if (!title.isEmpty()) {
+                // Check if already existing
+                bool existing = false;
+                int nbf = ui.kOtherFilters->count();
+                for (int j = 0; !existing && j < nbf; ++j) {
+                    QListWidgetItem* item2 = ui.kOtherFilters->item(j);
+                    if (item2->data(1000).toString() == wc) {
+                        existing = true;
+                    }
+
+                }
+
+                // Add it if not existing
+                if (!existing) {
+                    QString icon = SKGMainPanel::getMainPanel()->getPluginByName(page->objectName())->icon();
+                    QListWidgetItem* item = new QListWidgetItem(KIcon(icon), title);
+                    item->setFlags(Qt::ItemIsUserCheckable | Qt::ItemIsEnabled);
+                    item->setCheckState(Qt::Unchecked);
+                    item->setData(1000, wc);
+                    item->setData(1001, icon);
+                    ui.kOtherFilters->addItem(item);
+                }
+            }
+        }
+    }
 }
 
 void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTransaction)
@@ -902,7 +953,7 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
                     attCol = "";
                 }
                 if (attCol.startsWith(QLatin1String("p_"))) {
-		    attCol = getWhereClauseForProperty(attCol);
+                    attCol = getWhereClauseForProperty(attCol);
                 }
 
                 QStringList listAtt = m_attsForLinesAdded;
@@ -1269,7 +1320,7 @@ void SKGReportPluginWidget::setSettings()
 QString SKGReportPluginWidget::getWhereClauseForProperty(const QString& iProperty) const
 {
     QString propertyName = iProperty.right(iProperty.length() - 2);
-    return "IFNULL((SELECT t_value FROM parameters WHERE t_uuid_parent=v_suboperation_consolidated.id||'-suboperation' AND t_name='" % propertyName % "'), IFNULL((SELECT t_value FROM parameters WHERE t_uuid_parent=v_suboperation_consolidated.i_OPID||'-operation' AND t_name='" % propertyName % "'), '#NULL#'))";    
+    return "IFNULL((SELECT t_value FROM parameters WHERE t_uuid_parent=v_suboperation_consolidated.id||'-suboperation' AND t_name='" % propertyName % "'), IFNULL((SELECT t_value FROM parameters WHERE t_uuid_parent=v_suboperation_consolidated.i_OPID||'-operation' AND t_name='" % propertyName % "'), '#NULL#'))";
 }
 
 #include "skgreportpluginwidget.moc"
