@@ -333,14 +333,14 @@ SKGAdviceList SKGScheduledPlugin::advice(const QStringList& iIgnoredAdvice)
             ad.setPriority(4);
             ad.setShortMessage(i18nc("Advice on making the best (short)", "Scheduled operation '%1' not uptodate", name));
             ad.setLongMessage(i18nc("Advice on making the best (long)", "The scheduled operation '%1' does not have the amount of the last inserted operation (%2)", name, amountLastOperation));
-	    QList<SKGAdvice::SKGAdviceAction> autoCorrections;
-	    {
-	      SKGAdvice::SKGAdviceAction a;
-	      a.Title=i18nc("Advice on making the best (action)", "Update the next scheduled operation amount (%1)", amountLastOperation);
-	      a.IconName="system-run";
-	      a.IsRecommended=true;
-	      autoCorrections.push_back(a);
-	    }
+            QList<SKGAdvice::SKGAdviceAction> autoCorrections;
+            {
+                SKGAdvice::SKGAdviceAction a;
+                a.Title = i18nc("Advice on making the best (action)", "Update the next scheduled operation amount (%1)", amountLastOperation);
+                a.IconName = "system-run";
+                a.IsRecommended = true;
+                autoCorrections.push_back(a);
+            }
             ad.setAutoCorrections(autoCorrections);
             output.push_back(ad);
         }
@@ -370,14 +370,14 @@ SKGAdviceList SKGScheduledPlugin::advice(const QStringList& iIgnoredAdvice)
                 ad.setPriority(4);
                 ad.setShortMessage(i18nc("Advice on making the best (short)", "Scheduled operation '%1' not uptodate", name));
                 ad.setLongMessage(i18nc("Advice on making the best (long)", "The scheduled operation '%1' does not have the date aligned with the last inserted operation (%2)", name, currentDate));
-		QList<SKGAdvice::SKGAdviceAction> autoCorrections;
-		{
-		  SKGAdvice::SKGAdviceAction a;
-		  a.Title=i18nc("Advice on making the best (action)", "Update the next scheduled operation date (%1)", newDate);
-		  a.IconName="system-run";
-		  a.IsRecommended=true;
-		  autoCorrections.push_back(a);
-		}
+                QList<SKGAdvice::SKGAdviceAction> autoCorrections;
+                {
+                    SKGAdvice::SKGAdviceAction a;
+                    a.Title = i18nc("Advice on making the best (action)", "Update the next scheduled operation date (%1)", newDate);
+                    a.IconName = "system-run";
+                    a.IsRecommended = true;
+                    autoCorrections.push_back(a);
+                }
                 ad.setAutoCorrections(autoCorrections);
                 output.push_back(ad);
             }
@@ -406,14 +406,14 @@ SKGAdviceList SKGScheduledPlugin::advice(const QStringList& iIgnoredAdvice)
             ad.setPriority(4);
             ad.setShortMessage(i18nc("Advice on making the best (short)", "Possible schedule '%1'", name));
             ad.setLongMessage(i18nc("Advice on making the best (long)", "The operation '%1' seems to be regularly created and could be scheduled", name));
-	    QList<SKGAdvice::SKGAdviceAction> autoCorrections;
-	    {
-	      SKGAdvice::SKGAdviceAction a;
-	      a.Title=i18nc("Advice on making the best (action)", "Monthly schedule the operation '%1'", name);
-	      a.IconName=icon();
-	      a.IsRecommended=true;
-	      autoCorrections.push_back(a);
-	    }
+            QList<SKGAdvice::SKGAdviceAction> autoCorrections;
+            {
+                SKGAdvice::SKGAdviceAction a;
+                a.Title = i18nc("Advice on making the best (action)", "Monthly schedule the operation '%1'", name);
+                a.IconName = icon();
+                a.IsRecommended = false;
+                autoCorrections.push_back(a);
+            }
             ad.setAutoCorrections(autoCorrections);
             output.push_back(ad);
         }
