@@ -46,6 +46,7 @@
 #include "skgunitvalueobject.h"
 #include "skgbudgetruleobject.h"
 #include "skgbudgetobject.h"
+#include <skgsuboperationobject.h>
 #include "skgtransactionmng.h"
 #include "skgtraces.h"
 #include "skgmainpanel.h"
@@ -271,8 +272,8 @@ QVariant SKGObjectModel::data(const QModelIndex& iIndex, int iRole) const
         QString att = m_listAttibutes[iIndex.column()];
         QString val = obj->getAttribute(att);
         if (((att == "t_bookmarked" || att == "t_status" || att == "i_NBRECURRENT" || att == "t_imported"))
-                || (att == "t_close")
-                || (att == "t_action_type")
+            || (att == "t_close")
+            || (att == "t_action_type")
            ) {
             if (iRole == Qt::UserRole) {
                 if (m_ruleTable && att == "t_action_type") {
@@ -328,9 +329,9 @@ QVariant SKGObjectModel::data(const QModelIndex& iIndex, int iRole) const
             double dval = SKGServices::stringToDouble(val);
             if (iRole == Qt::DisplayRole) {
                 if (att.endsWith(QLatin1String("_INCOME")) ||
-                        att.endsWith(QLatin1String("_EXPENSE")) ||
-                        (m_categoryTable && (att == "f_REALCURRENTAMOUNT" ||
-                                             att == "f_SUMCURRENTAMOUNT"))) {
+                    att.endsWith(QLatin1String("_EXPENSE")) ||
+                    (m_categoryTable && (att == "f_REALCURRENTAMOUNT" ||
+                                         att == "f_SUMCURRENTAMOUNT"))) {
                     if (dval == 0) {
                         return "";
                     }
@@ -389,6 +390,12 @@ QVariant SKGObjectModel::data(const QModelIndex& iIndex, int iRole) const
             }
 
             return SKGServices::stringToInt(val);
+        } else if (m_suboperationTable && att.startsWith(QLatin1String("p_"))) {
+            val = obj->getProperty(att.right(att.count() - 2));
+            if (val.isEmpty()) {
+                val = obj->getDocument()->getParameter(att.right(att.count() - 2), obj->getAttribute("i_OPID") % "-operation");
+            }
+            return val;
         }
         break;
     }
@@ -835,7 +842,7 @@ bool SKGObjectModel::setData(const QModelIndex& iIndex, const QVariant& iValue,
                 SKGAccountObject obj(getObject(iIndex));
                 SKGBEGINLIGHTTRANSACTION(*getDocument(),
                                          (static_cast<Qt::CheckState>(iValue.toInt()) == Qt::Checked ? i18nc("Noun, name of the user action", "Close account '%1'", obj.getName()) : i18nc("Noun, name of the user action", "Open account '%1'", obj.getName())), err);
-                if (abs(obj.getCurrentAmount()) > 0.01) {
+                if (qAbs(obj.getCurrentAmount()) > 0.01) {
                     err = getDocument()->sendMessage(i18nc("An information message",  "Warning, you closed an account with money"), SKGDocument::Warning);
                 }
                 IFOKDO(err, obj.setClosed(static_cast<Qt::CheckState>(iValue.toInt()) == Qt::Checked))
@@ -1124,6 +1131,10 @@ void SKGObjectModel::dataModified(const QString& iTableName, int iIdTransaction)
     }
 }
 
+QString SKGObjectModel::formatMoney(double iValue) const
+{
+    return getDocument()->formatMoney(iValue, static_cast<SKGDocumentBank*>(getDocument())->getPrimaryUnit(), false);
+}
 
 #include "skgobjectmodel.moc"
 
