@@ -122,6 +122,30 @@ public:
      */
     virtual SKGError setBank(const SKGBankObject& iBank);
 
+    /**
+     * Get the linked account
+     * @param oAccount the linked account
+     * @return an object managing the error
+     *   @see SKGError
+     */
+    virtual SKGError getLinkedAccount(SKGAccountObject& oAccount) const;
+
+    /**
+     * Get the list of accounts linked to this one
+     * @param oAccounts the list of accounts linked
+     * @return an object managing the error
+     *   @see SKGError
+     */
+    virtual SKGError getLinkedByAccounts(SKGListSKGObjectBase& oAccounts) const;
+
+    /**
+     * Set the linked account
+     * @param iAccount the linked account
+     * @return an object managing the error
+     *   @see SKGError
+     */
+    virtual SKGError setLinkedAccount(const SKGAccountObject& iAccount);
+
     /**
      * Set the initial balance of this account
      * @param iBalance the balance
@@ -419,6 +443,15 @@ public:
      *   @see SKGError
      */
     virtual SKGError merge(const SKGAccountObject& iAccount);
+
+    /**
+     * Create a transfert operation to balance a credit card account (based on pointed operations)
+     * @param iTargetAccount the target account  (should be the bank account)
+     * @param iDate the date of the balance operation
+     * @return an object managing the error
+     *   @see SKGError
+     */
+    virtual SKGError transferDeferredOperations(const SKGAccountObject& iTargetAccount, const QDate& iDate = QDate::currentDate());
 };
 /**
  * Declare the class
