@@ -548,7 +548,7 @@ SKGError SKGOperationObject::mergeAttribute(const SKGOperationObject& iDeletedOn
     }
 
     // Delete useless operation
-    IFOKDO(err, iDeletedOne.remove(false))
+    IFOKDO(err, iDeletedOne.remove(false, true))
     return err;
 }
 
