@@ -31,6 +31,7 @@
 #include <QMimeData>
 #include <QDir>
 #include <QColor>
+#include <float.h>
 
 #include "skgtraces.h"
 #include "skgdocument.h"
@@ -635,18 +636,28 @@ QVariant SKGObjectModelBase::data(const QModelIndex& iIndex, int iRole) const
 
                     // Is it possible to compute sums of f_CURRENTAMOUNT ?
                     int posAmount = m_listAttibutes.indexOf("f_CURRENTAMOUNT");
-                    if (posAmount != -1) {
+                    if (posAmount != -1 && nb>0) {
                         // Compute sums
                         double sum = 0.0;
+			double average = 0.0;
+			double min = DBL_MAX;
+			double max = -DBL_MAX;
                         for (int i = 0; i < nb ; ++i) {
-                            sum += data(SKGObjectModelBase::index(i, posAmount, iIndex), Qt::UserRole).toDouble();
+			    double amount = data(SKGObjectModelBase::index(i, posAmount, iIndex), Qt::UserRole).toDouble();
+                            sum += amount;
+			    max = qMax(max, amount);
+			    min = qMin(min, amount);
                         }
+                        average = sum / nb;
 
-                        return i18nc("How to display a grouping title. Here \"title (count)\"", "%1: %2 (%3) %4",
+                        return i18nc("How to display a grouping title. Here \"title (count) Sum= [min , average , max]\"", "%1: %2 (%3) Sum=%4 [%5 , %6 , %7]",
                                      getDocument()->getDisplay(m_groupby),
                                      obj->getAttribute("t_title"),
                                      nb,
-                                     formatMoney(sum)
+                                     formatMoney(sum),
+                                     formatMoney(min),
+                                     formatMoney(average),
+                                     formatMoney(max)
                                     );
                     } else {
                         return i18nc("How to display a grouping title. Here \"title (count)\"", "%1: %2 (%3)",
