@@ -34,9 +34,9 @@ class SKGTableWidgetDesignerPlugin : public QObject, public QDesignerCustomWidge
 public:
     /**
     * Constructor
-    * @param parent parent
+    * @param iParent parent
     */
-    explicit SKGTableWidgetDesignerPlugin(QObject* parent = 0);
+    explicit SKGTableWidgetDesignerPlugin(QObject* iParent = 0);
 
     /**
      * To know if the component is a container
@@ -94,10 +94,10 @@ public:
 
     /**
      * To get the widget representing the component
-     * @param parent the parent of the widget
+     * @param iParent the parent of the widget
      * @return the widget
      */
-    QWidget* createWidget(QWidget* parent);
+    QWidget* createWidget(QWidget* iParent);
 
     /**
      * Initilialize the component
