@@ -40,7 +40,9 @@ SKGTabWidget::SKGTabWidget(QWidget* iParent)
     m_timerSave.setSingleShot(true);
     connect(&m_timerSave, SIGNAL(timeout()), this, SLOT(onRefreshSaveIcon()), Qt::QueuedConnection);
     connect(tabBar(), SIGNAL(moveTab(int,int)), this, SLOT(onMoveTab(int,int)));
-    if (iParent) connect(static_cast<SKGMainPanel*>(iParent), SIGNAL(currentPageChanged()), this, SLOT(onCurrentChanged()));
+    if (iParent) {
+        connect(static_cast<SKGMainPanel*>(iParent), SIGNAL(currentPageChanged()), this, SLOT(onCurrentChanged()));
+    }
 
     // Use new KDE for moving tabs.
     KTabBar* tabbar = qobject_cast< KTabBar* >(tabBar());
@@ -122,8 +124,12 @@ void SKGTabWidget::onRefreshSaveIcon()
                 save->show();
                 save->setEnabled(true);
                 QStringList overlay;
-                if (page->isPin()) overlay.push_back("document-encrypt");
-                if (!page->getBookmarkID().isEmpty()) overlay.push_back("bookmarks");
+                if (page->isPin()) {
+                    overlay.push_back("document-encrypt");
+                }
+                if (!page->getBookmarkID().isEmpty()) {
+                    overlay.push_back("bookmarks");
+                }
                 save->setIcon(KIcon("document-save", NULL, overlay));
             } else if (page->isPin()) {
                 save->show();
